@@ -29,8 +29,8 @@ Cmd version: line oriented command interpreters.
 
 # Specific variables for pydoc
 __author__ = "MiKael Navarro <klnavarro@gmail.com>"
-__date__ = "April 2010"
-__version__ = "0.3.2"
+__date__ = "June 2010"
+__version__ = "0.3.3"
 
 # Include directives
 import os
@@ -126,6 +126,9 @@ NUMBER_MATCH    = r"(\d+)"
 TIMEDELTA_MATCH = r"(\d+)([WDHM])"
 DATE_MATCH      = r"(\d\d\d\d-\d\d-\d\d)"
 
+DOW             = ["mo", "tu", "we", "th", "fr", "sa", "su"]
+DOW_MATCH       = r"(" + "|".join (DOW) + ")"
+
 CONTEXT_REGEXP   = re.compile(CONTEXT_CHAR + WORD_MATCH, re.IGNORECASE)
 PROJECT_REGEXP   = re.compile("(?:" + PROJECT_CHAR 
                               + "|" + "\\" + PROJECT_ALT + ")" + WORD_MATCH, re.IGNORECASE)
@@ -140,6 +143,9 @@ START_REGEXP      = re.compile(START_CHAR + DATE_MATCH, re.IGNORECASE)
 DUE_REGEXP        = re.compile(DUE_CHAR + DATE_MATCH, re.IGNORECASE)
 END_REGEXP        = re.compile(END_CHAR + DATE_MATCH, re.IGNORECASE)
 
+START_DOW_REGEXP  = re.compile(START_CHAR + DOW_MATCH, re.IGNORECASE)
+DUE_DOW_REGEXP    = re.compile(DUE_CHAR + DOW_MATCH, re.IGNORECASE)
+END_DOW_REGEXP    = re.compile(END_CHAR + DOW_MATCH, re.IGNORECASE)
 
 #
 # Main GTD class.
@@ -271,9 +277,30 @@ class GTD(cmd.Cmd):
                 year, month, day = matches[-1].split('-')  # keep only last!
                 t[attr] = datetime.datetime(int(year), int(month), int(day))
 
+            else:  # check if it is in format of special day
+                title = eval(attr.upper() + '_DOW_REGEXP').sub('', title)
+
+                matches = eval(attr.upper() + '_DOW_REGEXP').findall(line)
+                if matches:
+                    today     = datetime.datetime.today()
+                    today_dow = today.weekday()  # monday is first
+                    given_dow = DOW.index(matches[-1])
+
+                    day_diff = given_dow - today_dow
+                    if day_diff < 0:
+                        day_diff += 7;
+
+                    day = today + datetime.timedelta (int (day_diff))
+                    t[attr] = day
+
         # Post-processing
         if t.has_key('end') or t.has_key('reference'):  # ignore completed and archived tasks
             t['complete'] = 100
+
+        # if due < start then correct due by setting it to start
+        if t.has_key('due') and t.has_key('start'):
+            if t['due'] < t['start']:
+                t['due'] = t['start']
             
         # Set the title
         t['title'] = " ".join(title.split())  # remove useless blank chars too
@@ -1177,8 +1204,8 @@ class GTD(cmd.Cmd):
             print self._disp(t)
 
         # Show number of tasks as result of search if more than 10
-        if len(tasks) > 10:
-            print "%d selected tasks found" % len(tasks)
+        if len(self.tasks_selected) > 10:
+            print "%d selected tasks found" % len(self.tasks_selected)
 
     #
     # Re-search.
@@ -1406,6 +1433,9 @@ def main(options, todotxt=TODO_TXT, todoyaml=None):
     if options and options.color:
         gtd_cmd.colorize = True
 
+    if options.quiet:
+        gtd_cmd.intro = ""
+
     try:
         # Enter the main cmdloop
         gtd_cmd.cmdloop()
@@ -1425,6 +1455,9 @@ if __name__ == "__main__":
                     action="store_true", dest="color", 
                     default=False,
                     help="activate color highlightment"),
+        make_option( "-q", "--quiet",
+                    action="store_true", dest="quiet",
+                    help="do not print the copyright message")
         ]
 
     parser = OptionParser(usage="python -O %prog [options] todo.txt", 
